You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by gi...@apache.org on 2023/03/13 23:50:31 UTC

[camel-k] branch main updated (0f92ecc9f -> 6224a21e8)

This is an automated email from the ASF dual-hosted git repository.

github-bot pushed a change to branch main
in repository https://gitbox.apache.org/repos/asf/camel-k.git


    from 0f92ecc9f chore(deps): bump github.com/onsi/gomega from 1.27.2 to 1.27.3
     new 2ac7f4bff chore: changelog automatic update
     new 6224a21e8 chore: nightly resource refresh

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 CHANGELOG.md                                       |  3 ++
 .../duck/client/internalclientset/fake/register.go | 14 ++++----
 .../client/internalclientset/scheme/register.go    | 14 ++++----
 config/crd/bases/camel.apache.org_builds.yaml      |  4 +--
 config/crd/bases/camel.apache.org_kamelets.yaml    |  2 ++
 docs/antora.yml                                    |  2 +-
 docs/modules/ROOT/partials/apis/camel-k-crds.adoc  |  2 +-
 helm/camel-k/crds/crd-build.yaml                   |  4 +--
 helm/camel-k/crds/crd-kamelet.yaml                 |  2 ++
 .../camel/applyconfiguration/camel/v1/buildspec.go | 18 +++++-----
 .../camel/clientset/versioned/fake/register.go     | 14 ++++----
 .../camel/clientset/versioned/scheme/register.go   | 14 ++++----
 pkg/resources/resources.go                         | 40 +++++++++++++++-------
 13 files changed, 78 insertions(+), 55 deletions(-)


[camel-k] 01/02: chore: changelog automatic update

Posted by gi...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

github-bot pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-k.git

commit 2ac7f4bffcfdf04b57f683d9553ec41088f006ed
Author: github-actions[bot] <41...@users.noreply.github.com>
AuthorDate: Mon Mar 13 23:44:37 2023 +0000

    chore: changelog automatic update
---
 CHANGELOG.md | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/CHANGELOG.md b/CHANGELOG.md
index 54c463172..39ab780c9 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -6,9 +6,12 @@
 
 **Closed issues:**
 
+- All KameletBindings reporting "Integration X does not have a readiness condition" error message [\#4129](https://github.com/apache/camel-k/issues/4129)
 - Kamelets are tried to unmarshal with old Flow [\#4117](https://github.com/apache/camel-k/issues/4117)
 - Upgrade Operator Framework SDK version [\#4105](https://github.com/apache/camel-k/issues/4105)
 - Automatic updates action failing [\#4073](https://github.com/apache/camel-k/issues/4073)
+- Build refactoring \(to address runtime decoupling\) [\#3831](https://github.com/apache/camel-k/issues/3831)
+- Add support for multiple data types and schemas in Kamelets [\#1980](https://github.com/apache/camel-k/issues/1980)
 
 ## [1.12.1-nightly](https://github.com/apache/camel-k/tree/1.12.1-nightly) (2023-03-08)
 


[camel-k] 02/02: chore: nightly resource refresh

Posted by gi...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

github-bot pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-k.git

commit 6224a21e8552ed46908ea940573cadf09adf4a27
Author: github-actions[bot] <41...@users.noreply.github.com>
AuthorDate: Mon Mar 13 23:50:25 2023 +0000

    chore: nightly resource refresh
---
 .../duck/client/internalclientset/fake/register.go | 14 ++++----
 .../client/internalclientset/scheme/register.go    | 14 ++++----
 config/crd/bases/camel.apache.org_builds.yaml      |  4 +--
 config/crd/bases/camel.apache.org_kamelets.yaml    |  2 ++
 docs/antora.yml                                    |  2 +-
 docs/modules/ROOT/partials/apis/camel-k-crds.adoc  |  2 +-
 helm/camel-k/crds/crd-build.yaml                   |  4 +--
 helm/camel-k/crds/crd-kamelet.yaml                 |  2 ++
 .../camel/applyconfiguration/camel/v1/buildspec.go | 18 +++++-----
 .../camel/clientset/versioned/fake/register.go     | 14 ++++----
 .../camel/clientset/versioned/scheme/register.go   | 14 ++++----
 pkg/resources/resources.go                         | 40 +++++++++++++++-------
 12 files changed, 75 insertions(+), 55 deletions(-)

diff --git a/addons/strimzi/duck/client/internalclientset/fake/register.go b/addons/strimzi/duck/client/internalclientset/fake/register.go
index 04aa54821..b03a9f805 100644
--- a/addons/strimzi/duck/client/internalclientset/fake/register.go
+++ b/addons/strimzi/duck/client/internalclientset/fake/register.go
@@ -38,14 +38,14 @@ var localSchemeBuilder = runtime.SchemeBuilder{
 // AddToScheme adds all types of this clientset into the given scheme. This allows composition
 // of clientsets, like in:
 //
-//	import (
-//	  "k8s.io/client-go/kubernetes"
-//	  clientsetscheme "k8s.io/client-go/kubernetes/scheme"
-//	  aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
-//	)
+//   import (
+//     "k8s.io/client-go/kubernetes"
+//     clientsetscheme "k8s.io/client-go/kubernetes/scheme"
+//     aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
+//   )
 //
-//	kclientset, _ := kubernetes.NewForConfig(c)
-//	_ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
+//   kclientset, _ := kubernetes.NewForConfig(c)
+//   _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
 //
 // After this, RawExtensions in Kubernetes types will serialize kube-aggregator types
 // correctly.
diff --git a/addons/strimzi/duck/client/internalclientset/scheme/register.go b/addons/strimzi/duck/client/internalclientset/scheme/register.go
index 7c58dd36c..bb376affd 100644
--- a/addons/strimzi/duck/client/internalclientset/scheme/register.go
+++ b/addons/strimzi/duck/client/internalclientset/scheme/register.go
@@ -38,14 +38,14 @@ var localSchemeBuilder = runtime.SchemeBuilder{
 // AddToScheme adds all types of this clientset into the given scheme. This allows composition
 // of clientsets, like in:
 //
-//	import (
-//	  "k8s.io/client-go/kubernetes"
-//	  clientsetscheme "k8s.io/client-go/kubernetes/scheme"
-//	  aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
-//	)
+//   import (
+//     "k8s.io/client-go/kubernetes"
+//     clientsetscheme "k8s.io/client-go/kubernetes/scheme"
+//     aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
+//   )
 //
-//	kclientset, _ := kubernetes.NewForConfig(c)
-//	_ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
+//   kclientset, _ := kubernetes.NewForConfig(c)
+//   _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
 //
 // After this, RawExtensions in Kubernetes types will serialize kube-aggregator types
 // correctly.
diff --git a/config/crd/bases/camel.apache.org_builds.yaml b/config/crd/bases/camel.apache.org_builds.yaml
index 2129e149f..033392e7d 100644
--- a/config/crd/bases/camel.apache.org_builds.yaml
+++ b/config/crd/bases/camel.apache.org_builds.yaml
@@ -80,8 +80,8 @@ spec:
             description: BuildSpec defines the Build operation to be executed
             properties:
               operatorNamespace:
-                description: The namespace of the operator in charge of this Build
-                  reconciliation.
+                description: The namespace where to run the builder Pod (must be the
+                  same of the operator in charge of this Build reconciliation).
                 type: string
               strategy:
                 description: The strategy that should be used to perform the Build.
diff --git a/config/crd/bases/camel.apache.org_kamelets.yaml b/config/crd/bases/camel.apache.org_kamelets.yaml
index 558c29c6a..41dcba0e4 100644
--- a/config/crd/bases/camel.apache.org_kamelets.yaml
+++ b/config/crd/bases/camel.apache.org_kamelets.yaml
@@ -160,6 +160,8 @@ spec:
                                       description: default is a default value for
                                         undefined object fields.
                                       x-kubernetes-preserve-unknown-fields: true
+                                    deprecated:
+                                      type: boolean
                                     description:
                                       type: string
                                     enum:
diff --git a/docs/antora.yml b/docs/antora.yml
index 1fe819cf8..5f13a3247 100644
--- a/docs/antora.yml
+++ b/docs/antora.yml
@@ -40,7 +40,7 @@ asciidoc:
     camel-quarkus-docs-version: 2.16.x
     quarkus-version: 2.16.0.Final
     buildah-version: 1.23.3
-    kaniko-version: 0.17.1
+    kaniko-version: 1.9.1
     kustomize-version: 4.5.4
     kubernetes-api-version: 0.25.6
     operator-fwk-api-version: 0.13.0
diff --git a/docs/modules/ROOT/partials/apis/camel-k-crds.adoc b/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
index 3652f067d..5cd8defff 100644
--- a/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
+++ b/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
@@ -441,7 +441,7 @@ string
 |
 
 
-The namespace of the operator in charge of this Build reconciliation.
+The namespace where to run the builder Pod (must be the same of the operator in charge of this Build reconciliation).
 
 |`timeout` +
 *https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.20/#duration-v1-meta[Kubernetes meta/v1.Duration]*
diff --git a/helm/camel-k/crds/crd-build.yaml b/helm/camel-k/crds/crd-build.yaml
index 2129e149f..033392e7d 100644
--- a/helm/camel-k/crds/crd-build.yaml
+++ b/helm/camel-k/crds/crd-build.yaml
@@ -80,8 +80,8 @@ spec:
             description: BuildSpec defines the Build operation to be executed
             properties:
               operatorNamespace:
-                description: The namespace of the operator in charge of this Build
-                  reconciliation.
+                description: The namespace where to run the builder Pod (must be the
+                  same of the operator in charge of this Build reconciliation).
                 type: string
               strategy:
                 description: The strategy that should be used to perform the Build.
diff --git a/helm/camel-k/crds/crd-kamelet.yaml b/helm/camel-k/crds/crd-kamelet.yaml
index 558c29c6a..41dcba0e4 100644
--- a/helm/camel-k/crds/crd-kamelet.yaml
+++ b/helm/camel-k/crds/crd-kamelet.yaml
@@ -160,6 +160,8 @@ spec:
                                       description: default is a default value for
                                         undefined object fields.
                                       x-kubernetes-preserve-unknown-fields: true
+                                    deprecated:
+                                      type: boolean
                                     description:
                                       type: string
                                     enum:
diff --git a/pkg/client/camel/clientset/versioned/fake/register.go b/pkg/client/camel/clientset/versioned/fake/register.go
index 327b4c8f0..449936a90 100644
--- a/pkg/client/camel/clientset/versioned/fake/register.go
+++ b/pkg/client/camel/clientset/versioned/fake/register.go
@@ -40,14 +40,14 @@ var localSchemeBuilder = runtime.SchemeBuilder{
 // AddToScheme adds all types of this clientset into the given scheme. This allows composition
 // of clientsets, like in:
 //
-//	import (
-//	  "k8s.io/client-go/kubernetes"
-//	  clientsetscheme "k8s.io/client-go/kubernetes/scheme"
-//	  aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
-//	)
+//   import (
+//     "k8s.io/client-go/kubernetes"
+//     clientsetscheme "k8s.io/client-go/kubernetes/scheme"
+//     aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
+//   )
 //
-//	kclientset, _ := kubernetes.NewForConfig(c)
-//	_ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
+//   kclientset, _ := kubernetes.NewForConfig(c)
+//   _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
 //
 // After this, RawExtensions in Kubernetes types will serialize kube-aggregator types
 // correctly.
diff --git a/pkg/client/camel/clientset/versioned/scheme/register.go b/pkg/client/camel/clientset/versioned/scheme/register.go
index 40ca6f0dc..6c3443318 100644
--- a/pkg/client/camel/clientset/versioned/scheme/register.go
+++ b/pkg/client/camel/clientset/versioned/scheme/register.go
@@ -40,14 +40,14 @@ var localSchemeBuilder = runtime.SchemeBuilder{
 // AddToScheme adds all types of this clientset into the given scheme. This allows composition
 // of clientsets, like in:
 //
-//	import (
-//	  "k8s.io/client-go/kubernetes"
-//	  clientsetscheme "k8s.io/client-go/kubernetes/scheme"
-//	  aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
-//	)
+//   import (
+//     "k8s.io/client-go/kubernetes"
+//     clientsetscheme "k8s.io/client-go/kubernetes/scheme"
+//     aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
+//   )
 //
-//	kclientset, _ := kubernetes.NewForConfig(c)
-//	_ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
+//   kclientset, _ := kubernetes.NewForConfig(c)
+//   _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
 //
 // After this, RawExtensions in Kubernetes types will serialize kube-aggregator types
 // correctly.
diff --git a/pkg/resources/resources.go b/pkg/resources/resources.go
index d5b793a12..761f5c8a1 100644
--- a/pkg/resources/resources.go
+++ b/pkg/resources/resources.go
@@ -81,9 +81,9 @@ var assets = func() http.FileSystem {
 		"/builder/builder-role-binding.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "builder-role-binding.yaml",
 			modTime:          time.Time{},
-			uncompressedSize: 1345,
+			uncompressedSize: 1351,
 
-			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xac\x53\x4d\x8f\xdb\x36\x10\xbd\xf3\x57\x3c\x58\x97\x04\x58\xcb\x6d\x4f\x85\x7a\x52\xf6\xa3\x15\x1a\xd8\x80\xe5\x34\xc8\x71\x4c\x8d\xa5\xa9\x25\x52\x25\xa9\x55\xdc\x5f\x5f\x90\x96\x37\x1b\xb4\x08\x7a\x08\x6f\x82\x86\xef\x63\xde\x63\x86\xf5\xf7\x3b\x2a\xc3\x7b\xd1\x6c\x3c\x37\x08\x16\xa1\x63\x94\x23\xe9\x8e\x51\xdb\x53\x98\xc9\x31\x9e\xec\x64\x1a\x0a\x62\x0d\xde\x94\xf5\xd3\x5b\x4c\xa6\x61\x07\x6b\x18\xd6\x61\xb0\x8e\x [...]
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xac\x53\x4d\x8f\xdb\x36\x10\xbd\xf3\x57\x3c\x58\x97\x04\x58\xcb\x6d\x4f\x85\x7b\x52\xf6\xa3\x15\x1a\xd8\x80\xe5\x34\xc8\x71\x4c\x8d\xa5\xa9\x25\x92\x25\xa9\x55\xdc\x5f\x5f\x90\xb6\x37\x1b\x14\x0d\x7a\x88\x6e\x02\x87\xef\x63\xde\x63\x81\xe5\xf7\xfb\x54\x81\xf7\xa2\xd9\x04\x6e\x11\x2d\x62\xcf\xa8\x1c\xe9\x9e\xd1\xd8\x63\x9c\xc9\x33\x9e\xec\x64\x5a\x8a\x62\x0d\xde\x54\xcd\xd3\x5b\x4c\xa6\x65\x0f\x6b\x18\xd6\x63\xb4\x9e\x [...]
 		},
 		"/builder/builder-role-openshift.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "builder-role-openshift.yaml",
@@ -117,9 +117,9 @@ var assets = func() http.FileSystem {
 		"/crd/bases/camel.apache.org_builds.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "camel.apache.org_builds.yaml",
 			modTime:          time.Time{},
-			uncompressedSize: 39510,
+			uncompressedSize: 39558,
 
-			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\x3d\x5d\x73\x23\x39\x6e\xef\xfe\x15\xa8\xf5\xc3\x78\xaa\x2c\x69\x77\xef\x23\x1b\xa7\x52\x29\x9d\x67\x77\xcf\x99\x0f\x4f\x46\xde\xb9\xbb\x37\x53\xdd\x90\xc4\x53\x37\xd9\x21\xd9\xd6\xe8\x52\xf9\xef\x29\x82\x64\xab\x25\xf5\x07\xdb\x1f\x3b\x97\x3b\xf1\x65\xc6\x2d\x12\x04\x41\x10\x00\x41\x10\x3c\x87\xd1\xf3\x95\xb3\x73\x78\xc7\x13\x14\x1a\x53\x30\x12\xcc\x0a\x61\x5a\xb0\x64\x85\x30\x93\x0b\xb3\x61\x0a\xe1\x27\x59\x8a\x [...]
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\x3d\x6b\x73\x23\x39\x6e\xdf\xfd\x2b\x50\xeb\x0f\xe3\xa9\xb2\xa4\xdd\xbd\x47\x36\x4e\xa5\x52\x3a\xcf\xee\x9e\x33\x0f\x4f\x46\xde\xb9\xbb\x6f\xa6\xba\x21\x89\xa7\x6e\xb2\x43\xb2\xad\xd1\xa5\xf2\xdf\x53\x04\xc9\x56\x4b\xea\x07\xdb\x8f\x9d\xcb\x9d\xf8\x65\xc6\x2d\x3e\x00\x10\x04\x40\x10\x04\xcf\x61\xf4\x7c\xe5\xec\x1c\xde\xf1\x04\x85\xc6\x14\x8c\x04\xb3\x42\x98\x16\x2c\x59\x21\xcc\xe4\xc2\x6c\x98\x42\xf8\x49\x96\x22\x [...]
 		},
 		"/crd/bases/camel.apache.org_camelcatalogs.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "camel.apache.org_camelcatalogs.yaml",
@@ -138,23 +138,23 @@ var assets = func() http.FileSystem {
 		"/crd/bases/camel.apache.org_integrationplatforms.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "camel.apache.org_integrationplatforms.yaml",
 			modTime:          time.Time{},
-			uncompressedSize: 170461,
+			uncompressedSize: 170855,
 
-			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\xbd\x7b\x73\xe3\x36\xb2\x28\xfe\xff\x7c\x0a\x94\x53\xa7\xc6\x33\x65\xc9\x33\xbb\x27\xbb\x39\x3e\x95\xba\xd7\xf1\x4c\x12\x67\x1e\xf6\xb1\x3d\xb3\xbb\x95\xa4\x22\x88\x6c\x49\x88\x41\x80\x07\x00\x65\x2b\xbf\xfd\x7d\xf7\x5b\x68\x00\x24\x25\x91\x20\x25\x79\x1e\x49\xc4\x54\xed\x8e\x6d\xa2\xd9\x00\x1a\xfd\x42\x3f\xbe\x20\x83\x87\x7b\x1e\x7d\x41\x5e\xb3\x04\x84\x86\x94\x18\x49\xcc\x0c\xc8\x69\x4e\x93\x19\x90\x6b\x39\x31\x [...]
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\xbd\x7b\x73\xe3\x36\xb2\x28\xfe\xff\x7c\x0a\x94\x53\xa7\xc6\x33\x65\xc9\x33\xbb\x27\xbb\x39\x3e\x95\xba\xd7\xf1\x4c\x12\x67\x1e\xf6\xb1\x3d\xb3\xbb\x95\xa4\x22\x88\x6c\x49\x88\x41\x80\x07\x00\x65\x2b\xbf\xfd\x7d\xf7\x5b\x68\x00\x24\x25\x91\x20\x25\x79\x1e\x49\xc4\x54\xed\x8e\x6d\xa2\xd9\x00\x1a\xfd\x42\x3f\xbe\x20\x83\x87\x7b\x1e\x7d\x41\x5e\xb3\x04\x84\x86\x94\x18\x49\xcc\x0c\xc8\x69\x4e\x93\x19\x90\x6b\x39\x31\x [...]
 		},
 		"/crd/bases/camel.apache.org_integrations.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "camel.apache.org_integrations.yaml",
 			modTime:          time.Time{},
-			uncompressedSize: 492115,
+			uncompressedSize: 492312,
 
-			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\xfd\x7b\x73\x1b\x37\x96\x30\x8c\xff\x9f\x4f\x81\x72\x52\x8f\xa4\x8d\x48\xd9\x99\xd9\xa9\x19\xff\xa6\x9e\x94\x56\x96\x13\xfd\x62\xcb\x2a\x4b\x49\x9e\x94\x93\x4d\xc0\x6e\x90\xc4\xa3\x6e\xa0\x17\x40\x53\xe2\xbc\x79\xbf\xfb\x5b\x38\x00\xfa\xc2\x5b\x1f\xb4\x48\xc7\xd9\x6d\x4c\x55\xc6\x14\xd9\xa7\x71\x39\x38\xf7\xcb\xe7\x64\xb4\xbf\xf1\xd9\xe7\xe4\x0d\x4f\x98\xd0\x2c\x25\x46\x12\x33\x67\xe4\xbc\xa0\xc9\x9c\x91\x5b\x39\x [...]
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\xfd\x7b\x73\x1b\x37\x96\x30\x8c\xff\x9f\x4f\x81\x72\x52\x8f\xa4\x8d\x48\xd9\x99\xd9\xa9\x19\xff\xa6\x9e\x94\x56\x96\x13\xfd\x62\xcb\x2a\x4b\x49\x9e\x94\x93\x4d\xc0\x6e\x90\xc4\xa3\x6e\xa0\x17\x40\x53\xe2\xbc\x79\xbf\xfb\x5b\x38\x00\xfa\xc2\x5b\x1f\xb4\x48\xc7\xd9\x6d\x4c\x55\xc6\x14\xd9\xa7\x71\x39\x38\xf7\xcb\xe7\x64\xb4\xbf\xf1\xd9\xe7\xe4\x0d\x4f\x98\xd0\x2c\x25\x46\x12\x33\x67\xe4\xbc\xa0\xc9\x9c\x91\x5b\x39\x [...]
 		},
 		"/crd/bases/camel.apache.org_kameletbindings.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "camel.apache.org_kameletbindings.yaml",
 			modTime:          time.Time{},
-			uncompressedSize: 571740,
+			uncompressedSize: 571953,
 
-			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\xfd\x79\x73\x1b\x37\xd6\x28\x8c\xff\xef\x4f\x81\x92\x53\x57\xd2\x13\x91\xb2\x33\x4b\xcd\xf8\x37\x75\x53\x1a\x59\x76\xf4\x8b\x2d\xb3\x2c\x25\xb9\x29\x27\x4f\x02\x76\x83\x24\xae\xba\x81\x7e\x00\x34\x25\xe6\xf5\xfb\xdd\xdf\xc2\x01\xd0\x0b\x37\xe1\x34\x25\x8d\x3c\xd3\x98\xaa\x8c\x49\xb1\x4f\x63\x3b\xfb\xf6\x9c\x0c\xee\x6f\x3c\x7b\x4e\xde\xf1\x84\x09\xcd\x52\x62\x24\x31\x33\x46\x4e\x0a\x9a\xcc\x18\xb9\x94\x13\x73\x43\x [...]
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\xfd\x79\x73\x1b\x37\xd6\x28\x8c\xff\xef\x4f\x81\x92\x53\x57\xd2\x13\x91\xb2\x33\x4b\xcd\xf8\x37\x75\x53\x1a\x59\x76\xf4\x8b\x2d\xb3\x2c\x25\xb9\x29\x27\x4f\x02\x76\x83\x24\xae\xba\x81\x7e\x00\x34\x25\xe6\xf5\xfb\xdd\xdf\xc2\x01\xd0\x0b\x37\xe1\x34\x25\x8d\x3c\xd3\x98\xaa\x8c\x49\xb1\x4f\x63\x3b\xfb\xf6\x9c\x0c\xee\x6f\x3c\x7b\x4e\xde\xf1\x84\x09\xcd\x52\x62\x24\x31\x33\x46\x4e\x0a\x9a\xcc\x18\xb9\x94\x13\x73\x43\x [...]
 		},
 		"/crd/bases/camel.apache.org_kamelets.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "camel.apache.org_kamelets.yaml",
@@ -174,6 +174,13 @@ var assets = func() http.FileSystem {
 
 			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xc4\x56\x4d\x8f\xe2\x46\x10\xbd\xfb\x57\x3c\xe1\xcb\xae\x34\x18\x66\x4f\x2b\xe7\xe4\x0c\x4c\xd6\xca\xc6\x20\xcc\x66\xb4\xa7\xa8\x69\x17\x76\x8b\x76\xb7\xd3\xdd\x86\x25\xbf\x3e\x6a\x83\x19\x60\x3e\x92\x89\x46\x8a\x4f\xd8\x55\xf5\xea\xd5\x7b\xd5\x36\x21\x86\xef\x77\x05\x21\xbe\x0a\x4e\xca\x52\x01\xa7\xe1\x2a\x42\xd2\x30\x5e\x11\x72\xbd\x76\x3b\x66\x08\xf7\xba\x55\x05\x73\x42\x2b\x7c\x48\xf2\xfb\x8f\x68\x55\x41\x06\x5a\x [...]
 		},
+		"/manager/operator-pvc.yaml": &vfsgen۰CompressedFileInfo{
+			name:             "operator-pvc.yaml",
+			modTime:          time.Time{},
+			uncompressedSize: 1156,
+
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xac\x53\xc1\x8e\xdb\x36\x10\xbd\xf3\x2b\x1e\xac\x4b\x02\xac\xbd\x69\x8e\xee\xc9\x75\xec\x56\x68\x2a\x17\x96\x93\x45\x8e\x63\x72\x2c\x0d\x96\x22\x55\x92\x5a\xc5\x7f\x5f\x50\x96\x93\x0d\x72\x0d\x6f\xe3\x19\xbf\x79\x6f\xde\x53\x81\xe5\xaf\x7b\xaa\xc0\x47\xd1\xec\x22\x1b\x24\x8f\xd4\x32\x36\x3d\xe9\x96\x51\xfb\x4b\x1a\x29\x30\xf6\x7e\x70\x86\x92\x78\x87\x37\x9b\x7a\xff\x16\x83\x33\x1c\xe0\x1d\xc3\x07\x74\x3e\xb0\x2a\xa0\x [...]
+		},
 		"/manager/operator-service-account.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "operator-service-account.yaml",
 			modTime:          time.Time{},
@@ -195,6 +202,13 @@ var assets = func() http.FileSystem {
 
 			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xac\x53\xcd\x6e\xa3\x3c\x14\xdd\xfb\x29\x8e\xc2\xa6\x95\x92\x50\x7d\xcb\x7c\x2b\xa6\x25\x1a\xd4\x0c\x91\x0a\x9d\xaa\xab\xca\x81\x0b\x5c\x0d\xd8\x1e\xdb\x94\xe6\xed\x47\x26\xc9\xb4\xd5\x6c\xeb\x9d\xe1\xfa\xfc\xf8\x1c\x47\x58\x7d\xdd\x12\x11\x76\x5c\x91\x72\x54\xc3\x6b\xf8\x8e\x90\x18\x59\x75\x84\x42\x37\x7e\x92\x96\xb0\xd5\xa3\xaa\xa5\x67\xad\x70\x95\x14\xdb\x6b\x8c\xaa\x26\x0b\xad\x08\xda\x62\xd0\x96\x44\x84\x4a\x2b\x [...]
 		},
+		"/manager/patch-install-default-pvc.yaml": &vfsgen۰CompressedFileInfo{
+			name:             "patch-install-default-pvc.yaml",
+			modTime:          time.Time{},
+			uncompressedSize: 1206,
+
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xac\x53\x4d\x4f\xeb\x38\x14\xdd\xfb\x57\x1c\x35\x1b\x90\xda\x06\xb1\xec\xac\x3a\xa5\xd5\x44\xc3\xa4\x23\x52\x40\x2c\xdd\xe4\x36\xb9\x22\xfe\x78\xb6\xd3\xd0\x7f\xff\xe4\xa4\x7d\x80\xd8\xb0\xc0\x3b\xcb\xd7\xe7\xc3\xe7\x38\xc1\xec\xe7\x96\x48\x70\xcf\x25\x69\x4f\x15\x82\x41\x68\x08\x4b\x2b\xcb\x86\x50\x98\x43\xe8\xa5\x23\x6c\x4c\xa7\x2b\x19\xd8\x68\x5c\x2d\x8b\xcd\x35\x3a\x5d\x91\x83\xd1\x04\xe3\xa0\x8c\x23\x91\xa0\x34\x [...]
+		},
 		"/manager/patch-log-level.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "patch-log-level.yaml",
 			modTime:          time.Time{},
@@ -611,9 +625,9 @@ var assets = func() http.FileSystem {
 		"/traits.yaml": &vfsgen۰CompressedFileInfo{
 			name:             "traits.yaml",
 			modTime:          time.Time{},
-			uncompressedSize: 64398,
+			uncompressedSize: 64511,
 
-			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\x7d\xfd\x77\x1b\x37\x92\xe0\xef\xfe\x2b\xf0\xb8\xb7\x4f\x92\x8f\x1f\x4a\x66\x33\x9b\xd5\x9d\x77\x4e\x71\x9c\x8c\x12\x7f\xe8\x2c\x25\xb3\xf3\x7c\x7e\x43\xb0\x1b\x24\x61\x36\x81\x1e\x00\x2d\x89\xb9\xb9\xff\xfd\x1e\xaa\x0a\x1f\xdd\x6c\x4a\x94\x6d\x65\x47\x3b\x99\x79\x2f\x16\xc9\xee\x42\xa1\x50\x28\x14\xea\xd3\x19\x2e\x9d\x3d\x79\x32\x62\x8a\xaf\xc5\x09\xfb\x9d\x2d\x78\x25\x9e\x30\x56\x57\xdc\xcd\xb5\x59\x9f\xb0\x39\x [...]
+			compressedContent: []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\x7d\xfd\x77\x1b\x37\x92\xe0\xef\xfe\x2b\xf0\xb8\xb7\x4f\x92\x8f\x1f\x4a\x66\x33\x9b\xd5\x9d\x77\x4e\x71\x9c\x8c\x12\x7f\xe8\x2c\x25\xb3\xf3\x7c\x7e\x43\xb0\x1b\x24\x61\x36\x81\x1e\x00\x2d\x89\xb9\xb9\xff\xfd\x1e\xaa\x0a\x1f\xdd\x6c\x4a\x94\x6d\x65\x47\x3b\x99\x79\x2f\x16\xc9\xee\x42\xa1\x50\x28\x14\xea\xd3\x19\x2e\x9d\x3d\x79\x32\x62\x8a\xaf\xc5\x09\xfb\x9d\x2d\x78\x25\x9e\x30\x56\x57\xdc\xcd\xb5\x59\x9f\xb0\x39\x [...]
 		},
 	}
 	fs["/"].(*vfsgen۰DirInfo).entries = []os.FileInfo{
@@ -658,9 +672,11 @@ var assets = func() http.FileSystem {
 	}
 	fs["/manager"].(*vfsgen۰DirInfo).entries = []os.FileInfo{
 		fs["/manager/operator-deployment.yaml"].(os.FileInfo),
+		fs["/manager/operator-pvc.yaml"].(os.FileInfo),
 		fs["/manager/operator-service-account.yaml"].(os.FileInfo),
 		fs["/manager/patch-image-pull-policy-always.yaml"].(os.FileInfo),
 		fs["/manager/patch-install-default-kamelets.yaml"].(os.FileInfo),
+		fs["/manager/patch-install-default-pvc.yaml"].(os.FileInfo),
 		fs["/manager/patch-log-level.yaml"].(os.FileInfo),
 		fs["/manager/patch-node-selector.yaml"].(os.FileInfo),
 		fs["/manager/patch-ports.yaml"].(os.FileInfo),
diff --git a/pkg/client/camel/applyconfiguration/camel/v1/buildspec.go b/pkg/client/camel/applyconfiguration/camel/v1/buildspec.go
index b3bdb76ac..c928e89eb 100644
--- a/pkg/client/camel/applyconfiguration/camel/v1/buildspec.go
+++ b/pkg/client/camel/applyconfiguration/camel/v1/buildspec.go
@@ -27,11 +27,11 @@ import (
 // BuildSpecApplyConfiguration represents an declarative configuration of the BuildSpec type for use
 // with apply.
 type BuildSpecApplyConfiguration struct {
-	Tasks             []TaskApplyConfiguration `json:"tasks,omitempty"`
-	Strategy          *camelv1.BuildStrategy   `json:"strategy,omitempty"`
-	ToolImage         *string                  `json:"toolImage,omitempty"`
-	OperatorNamespace *string                  `json:"operatorNamespace,omitempty"`
-	Timeout           *metav1.Duration         `json:"timeout,omitempty"`
+	Tasks               []TaskApplyConfiguration `json:"tasks,omitempty"`
+	Strategy            *camelv1.BuildStrategy   `json:"strategy,omitempty"`
+	ToolImage           *string                  `json:"toolImage,omitempty"`
+	BuilderPodNamespace *string                  `json:"operatorNamespace,omitempty"`
+	Timeout             *metav1.Duration         `json:"timeout,omitempty"`
 }
 
 // BuildSpecApplyConfiguration constructs an declarative configuration of the BuildSpec type for use with
@@ -69,11 +69,11 @@ func (b *BuildSpecApplyConfiguration) WithToolImage(value string) *BuildSpecAppl
 	return b
 }
 
 // WithOperatorNamespace sets the OperatorNamespace field in the declarative configuration to the given value
 // and returns the receiver, so that objects can be built by chaining "With" function invocations.
-// If called multiple times, the OperatorNamespace field is set to the value of the last call.
-func (b *BuildSpecApplyConfiguration) WithOperatorNamespace(value string) *BuildSpecApplyConfiguration {
-	b.OperatorNamespace = &value
+// If called multiple times, the BuilderPodNamespace field is set to the value of the last call.
+func (b *BuildSpecApplyConfiguration) WithBuilderPodNamespace(value string) *BuildSpecApplyConfiguration {
+	b.BuilderPodNamespace = &value
 	return b
 }
 
@@ -69,11 +69,11 @@ func (b *BuildSpecApplyConfiguration) WithToolImage(value string) *BuildSpecAppl
 }
 
-// WithOperatorNamespace sets the OperatorNamespace field in the declarative configuration to the given value
+// WithBuilderPodNamespace sets the BuilderPodNamespace field in the declarative configuration to the given value
 // and returns the receiver, so that objects can be built by chaining "With" function invocations.